# Amulet-Editor

A Minecraft world editor and converter that supports all versions since Java 1.12 and Bedrock 1.7.

## Running compiled builds

Download the installer for your operating system from the list of [compiled builds](https://github.com/Amulet-Team/Amulet-Editor/releases).

Double click on the installer when downloaded and follow the installation steps. It can then be run and uninstalled like a normal program.

## Running from Source

**If you are running a compiled build you do NOT need to do this.**

1) Install [Python 3.9+](https://www.python.org/)
2) We recommend setting up a [python virtual environment](https://docs.python.org/3/tutorial/venv.html) so you don't run into issues with dependency conflicts.
3) Clone or download the repository source code.
4) In the source code directory run `python -m pip install .` to install the library and all its dependencies. Linux and MacOS users will need to use `python3`
5) run `amulet_editor` to run the program
